@@ -10,6 +10,7 @@ from pywapor.general.processing_functions import open_ds, remove_ds, save_ds
 import pywapor.collect.accounts as accounts
 from shapely.geometry.polygon import Polygon
 from shapely.geometry import shape
+import copy
 import pywapor.collect.protocol.opendap as opendap
 from pywapor.enhancers.dem import calc_slope, calc_aspect
 import numpy as np
@@ -175,20 +176,16 @@ def download(folder, latlim, lonlim, product_name = "30M", req_vars = ["z"], var
     """
     folder = os.path.join(folder, "SRTM")
     
-    appending = False
     fn = os.path.join(folder, f"{product_name}.nc")
+    req_vars_orig = copy.deepcopy(req_vars)
     if os.path.isfile(fn):
-        os.rename(fn, fn.replace(".nc", "_to_be_appended.nc"))
-        existing_ds = open_ds(fn.replace(".nc", "_to_be_appended.nc"))
-        if np.all([x in existing_ds.data_vars for x in req_vars]):
+        existing_ds = open_ds(fn)
+        req_vars_new = list(set(req_vars).difference(set(existing_ds.data_vars)))
+        if len(req_vars_new) > 0:
+            req_vars = req_vars_new
             existing_ds = existing_ds.close()
-            os.rename(fn.replace(".nc", "_to_be_appended.nc"), fn)
-            existing_ds = open_ds(fn)
-            return existing_ds[req_vars]
         else:
-            appending = True
-            fn = os.path.join(folder, f"{product_name}_appendix.nc")
-            req_vars = [x for x in req_vars if x not in existing_ds.data_vars]
+            return existing_ds[req_vars_orig]
 
     spatial_buffer = True
     if spatial_buffer:
@@ -216,21 +213,12 @@ def download(folder, latlim, lonlim, product_name = "30M", req_vars = ["z"], var
     un_pw = accounts.get("NASA")
     request_dims = True
 
-    ds_new = opendap.download(fn, product_name, coords, 
+    ds = opendap.download(fn, product_name, coords, 
                 variables, post_processors, fn_func, url_func, un_pw = un_pw, 
                 tiles = tiles, data_source_crs = data_source_crs, parallel = parallel, 
                 spatial_tiles = spatial_tiles, request_dims = request_dims)
 
-    if appending:
-        ds = xr.merge([ds_new, existing_ds])
-        lbl = f"Appending new variables (`{'`, `'.join(req_vars)}`) to existing file."
-        ds = save_ds(ds, os.path.join(folder, f"{product_name}.nc"), encoding = "initiate", label = lbl)
-        remove_ds(ds_new)
-        remove_ds(existing_ds)
-    else:
-        ds = ds_new
-
-    return ds
+    return ds[req_vars_orig]
 
 if __name__ == "__main__":
 
